@@ -11,16 +11,19 @@ And follow the interactive documentation.
 """
 
 from pytezos.client import PyTezosClient
-from pytezos.contract.interface import Contract, ContractInterface
+from pytezos.contract.interface import Contract
+from pytezos.contract.interface import ContractInterface
 from pytezos.crypto.key import Key
 from pytezos.logging import logger
-from pytezos.michelson.forge import forge_micheline, unforge_micheline
+from pytezos.michelson.forge import forge_micheline
+from pytezos.michelson.forge import unforge_micheline
 from pytezos.michelson.format import micheline_to_michelson
 from pytezos.michelson.micheline import MichelsonRuntimeError
 from pytezos.michelson.parse import michelson_to_micheline
-from pytezos.michelson.types.base import MichelsonType, Undefined
+from pytezos.michelson.types.base import MichelsonType
+from pytezos.michelson.types.base import Undefined
 from pytezos.michelson.types.core import Unit
 
-__version__ = '3.6.0'
+__version__ = '3.6.1'
 
 pytezos = PyTezosClient()
