@@ -1,9 +1,14 @@
-from typing import List, Tuple, cast
+from typing import List
+from typing import Tuple
+from typing import cast
 
 from pytezos.context.abstract import AbstractContext
-from pytezos.michelson.instructions.base import MichelsonInstruction, format_stdout
+from pytezos.michelson.instructions.base import MichelsonInstruction
+from pytezos.michelson.instructions.base import format_stdout
 from pytezos.michelson.stack import MichelsonStack
-from pytezos.michelson.types import MichelsonType, OrType, PairType
+from pytezos.michelson.types import MichelsonType
+from pytezos.michelson.types import OrType
+from pytezos.michelson.types import PairType
 
 
 def execute_cxr(prim: str, stack: MichelsonStack, stdout: List[str], idx: int):
@@ -15,7 +20,6 @@ def execute_cxr(prim: str, stack: MichelsonStack, stdout: List[str], idx: int):
 
 
 class CarInstruction(MichelsonInstruction, prim='CAR'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_cxr(cls.prim, stack, stdout, 0)  # type: ignore
@@ -23,7 +27,6 @@ class CarInstruction(MichelsonInstruction, prim='CAR'):
 
 
 class CdrInstruction(MichelsonInstruction, prim='CDR'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         execute_cxr(cls.prim, stack, stdout, 1)  # type: ignore
@@ -31,7 +34,6 @@ class CdrInstruction(MichelsonInstruction, prim='CDR'):
 
 
 class GetnInstruction(MichelsonInstruction, prim='GET', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         pair = cast(PairType, stack.pop1())
@@ -44,7 +46,6 @@ class GetnInstruction(MichelsonInstruction, prim='GET', args_len=1):
 
 
 class UpdatenInstruction(MichelsonInstruction, prim='UPDATE', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         element, pair = cast(Tuple[MichelsonType, PairType], stack.pop2())
@@ -57,7 +58,6 @@ class UpdatenInstruction(MichelsonInstruction, prim='UPDATE', args_len=1):
 
 
 class LeftInstruction(MichelsonInstruction, prim='LEFT', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         left = stack.pop1()
@@ -68,7 +68,6 @@ class LeftInstruction(MichelsonInstruction, prim='LEFT', args_len=1):
 
 
 class RightInstruction(MichelsonInstruction, prim='RIGHT', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         right = stack.pop1()
@@ -79,7 +78,6 @@ class RightInstruction(MichelsonInstruction, prim='RIGHT', args_len=1):
 
 
 class PairInstruction(MichelsonInstruction, prim='PAIR'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         left, right = stack.pop2()
@@ -90,7 +88,6 @@ class PairInstruction(MichelsonInstruction, prim='PAIR'):
 
 
 class UnpairInstruction(MichelsonInstruction, prim='UNPAIR'):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         pair = cast(PairType, stack.pop1())
@@ -103,7 +100,6 @@ class UnpairInstruction(MichelsonInstruction, prim='UNPAIR'):
 
 
 class PairnInstruction(MichelsonInstruction, prim='PAIR', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         count = cls.args[0].get_int()  # type: ignore
@@ -116,7 +112,6 @@ class PairnInstruction(MichelsonInstruction, prim='PAIR', args_len=1):
 
 
 class UnpairnInstruction(MichelsonInstruction, prim='UNPAIR', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         count = cls.args[0].get_int()  # type: ignore
