@@ -1,9 +1,12 @@
 # Inspired by https://github.com/jansorg/tezos-intellij/blob/master/grammar/michelson.bnf
 import json
 import re
-from typing import List, Optional
+from typing import List
+from typing import Optional
 
-from ply.lex import Lexer, LexToken, lex  # type: ignore
+from ply.lex import Lexer  # type: ignore
+from ply.lex import LexToken
+from ply.lex import lex
 from ply.yacc import yacc  # type: ignore
 
 from pytezos.michelson.macros import expand_macro
@@ -11,8 +14,14 @@ from pytezos.michelson.macros import expr as make_expr
 from pytezos.michelson.tags import prim_tags
 
 
-class MichelsonParserError(ValueError):
+def doc(docstring):
+    def decorate(func):
+        func.__doc__ = docstring
+        return func
+    return decorate
 
+
+class MichelsonParserError(ValueError):
     def __init__(self, token: LexToken, message=None):
         message = message or f'failed to parse expression {token}'
         super(MichelsonParserError, self).__init__(message)
@@ -29,8 +38,7 @@ class Sequence(list):
 
 
 class SimpleMichelsonLexer(Lexer):
-    tokens = ('INT', 'BYTE', 'STR', 'ANNOT', 'PRIM',
-              'LEFT_CURLY', 'RIGHT_CURLY', 'LEFT_PAREN', 'RIGHT_PAREN', 'SEMI')
+    tokens = ('INT', 'BYTE', 'STR', 'ANNOT', 'PRIM', 'LEFT_CURLY', 'RIGHT_CURLY', 'LEFT_PAREN', 'RIGHT_PAREN', 'SEMI')
 
     t_INT = r'-?[0-9]+'
     t_BYTE = r'0x[A-Fa-f0-9]*'
@@ -58,119 +66,116 @@ class SimpleMichelsonLexer(Lexer):
         return t
 
 
-class MichelsonParser(object):
-    """ Customizable Michelson parser
-    """
+class MichelsonParser:
+    """Customizable Michelson parser"""
+
     tokens = SimpleMichelsonLexer.tokens
 
+    @doc('''instr : expr 
+                  | empty''')
     def p_instr(self, p):
-        '''instr : expr
-                 | empty
-        '''
         p[0] = p[1]
 
+    @doc('instr : INT')
     def p_instr_int(self, p):
-        '''instr : INT'''
         p[0] = {'int': p[1]}
 
+    @doc('instr : BYTE')
     def p_instr_byte(self, p):
-        '''instr : BYTE'''
         p[0] = {'bytes': p[1][2:]}  # strip 0x prefix
 
+    @doc('instr : STR')
     def p_instr_str(self, p):
-        '''instr : STR'''
         p[0] = {'string': json.loads(p[1])}
 
+    @doc('instr : instr SEMI instr')
     def p_instr_list(self, p):
-        '''instr : instr SEMI instr'''
-        p[0] = list()
+        p[0] = []
         for i in [p[1], p[3]]:
             if type(i) is list:
                 p[0].extend(i)
             elif i is not None:
                 p[0].append(i)
 
+    @doc('instr : LEFT_CURLY instr RIGHT_CURLY')
     def p_instr_subseq(self, p):
-        '''instr : LEFT_CURLY instr RIGHT_CURLY'''
         p[0] = Sequence()
         if type(p[2]) is list:
             p[0].extend(p[2])
         elif p[2] is not None:
             p[0].append(p[2])
 
+    @doc('expr : PRIM annots args')
     def p_expr(self, p):
-        '''expr : PRIM annots args'''
         prim = p[1]
         if prim in prim_tags or prim in self.extra_primitives:
             expr = make_expr(
-                prim=prim, 
-                annots=p[2] or [], 
-                args=p[3] or []
+                prim=prim,
+                annots=p[2] or [],
+                args=p[3] or [],
             )
         else:
             try:
                 expr = expand_macro(
                     prim=prim,
                     annots=p[2] or [],
-                    args=p[3] or []
+                    args=p[3] or [],
                 )
             except AssertionError as e:
                 raise MichelsonParserError(p.slice[1], str(e)) from e
         p[0] = Sequence(expr) if isinstance(expr, list) else expr
 
+    @doc('''annots : annot 
+                   | empty''')
     def p_annots(self, p):
-        '''annots : annot
-                  | empty
-        '''
         if p[1] is not None:
             p[0] = [p[1]]
 
+    @doc('annots : annots annot')
     def p_annots_list(self, p):
-        '''annots : annots annot'''
-        p[0] = list()
+        p[0] = []
         if type(p[1]) == list:
             p[0].extend(p[1])
         if p[2] is not None:
             p[0].append(p[2])
 
+    @doc('annot : ANNOT')
     def p_annot(self, p):
-        '''annot : ANNOT'''
         p[0] = p[1]
 
+    @doc('''args : arg 
+                 | empty''')
     def p_args(self, p):
-        '''args : arg
-                | empty
-        '''
-        p[0] = list()
+        p[0] = []
         if p[1] is not None:
             p[0].append(p[1])
 
+    @doc('args : args arg')
     def p_args_list(self, p):
-        '''args : args arg'''
-        p[0] = list()
+        p[0] = []
         if type(p[1]) == list:
             p[0].extend(p[1])
         if p[2] is not None:
             p[0].append(p[2])
 
+    @doc('arg : PRIM')
     def p_arg_prim(self, p):
-        '''arg : PRIM'''
         p[0] = {'prim': p[1]}
 
+    @doc('arg : INT')
     def p_arg_int(self, p):
-        '''arg : INT'''
         p[0] = {'int': p[1]}
 
+    @doc('arg : BYTE')
     def p_arg_byte(self, p):
-        '''arg : BYTE'''
         p[0] = {'bytes': p[1][2:]}  # strip 0x prefix
 
+    @doc('arg : STR')
     def p_arg_str(self, p):
-        '''arg : STR'''
         p[0] = {'string': json.loads(p[1])}
 
+    @doc('arg : LEFT_CURLY instr RIGHT_CURLY')
     def p_arg_subseq(self, p):
-        '''arg : LEFT_CURLY instr RIGHT_CURLY'''
         if type(p[2]) == list:
             p[0] = p[2]
         elif p[2] is not None:
@@ -178,18 +183,19 @@ class MichelsonParser(object):
         else:
             p[0] = []
 
+    @doc('arg : LEFT_PAREN expr RIGHT_PAREN')
     def p_arg_group(self, p):
-        '''arg : LEFT_PAREN expr RIGHT_PAREN'''
         p[0] = p[2]
 
+    @doc('empty :')
     def p_empty(self, p):
-        '''empty :'''
+        ...
 
     def p_error(self, p):
         raise MichelsonParserError(p)
 
     def __init__(self, debug=False, write_tables=False, extra_primitives: Optional[List[str]] = None):
-        """ Initialize Michelson parser
+        """Initialize Michelson parser
 
         :param debug: Verbose output
         :param write_tables: Store PLY output
@@ -204,7 +210,7 @@ class MichelsonParser(object):
         self.extra_primitives = extra_primitives or []
 
     def parse(self, code):
-        """ Parse Michelson source.
+        """Parse Michelson source.
 
         :param code: Michelson source
         :returns: Micheline expression
@@ -215,7 +221,7 @@ class MichelsonParser(object):
 
 
 def michelson_to_micheline(data, parser=None):
-    """ Converts Michelson source text into a Micheline expression.
+    """Converts Michelson source text into a Micheline expression.
 
     :param data: Michelson string
     :param parser: custom Michelson parser (optional)
